@@ -2,24 +2,19 @@
 """
 :Author: CaiYouBin
 :Date: 2020-05-12 20:04:54
-:LastEditTime: 2021-02-24 15:58:45
+:LastEditTime: 2021-04-15 16:50:12
 :LastEditors: HuangJingCan
 :description: 基础接口
 """
-import random
-from copy import deepcopy
 from seven_cloudapp.handlers.top_base import *
 
-from seven_cloudapp.models.db_models.app.app_info_model import *
-from seven_cloudapp.models.db_models.base.base_info_model import *
-from seven_cloudapp.models.db_models.behavior.behavior_orm_model import *
+from seven_cloudapp.models.enum import OperationType
+from seven_cloudapp.models.seven_model import PageInfo
+from seven_cloudapp.models.behavior_model import *
 from seven_cloudapp.models.db_models.theme.theme_info_model import *
 from seven_cloudapp.models.db_models.skin.skin_info_model import *
 from seven_cloudapp.models.db_models.act.act_type_model import *
 from seven_cloudapp.models.db_models.ip.ip_series_model import *
-from seven_cloudapp.models.seven_model import PageInfo
-from seven_cloudapp.models.behavior_model import *
-from seven_cloudapp.models.enum import *
 
 from seven_cloudapp.handlers.server.act_s import ActTypeListHandler
 from seven_cloudapp.handlers.server.act_s import ActDelHandler
@@ -62,14 +57,18 @@ class ActCreateHandler(TopBaseHandler):
         app_id = app_info.app_id
         act_id = self.get_param("act_id")
         act_type = self.get_param("act_type")
-        act_model = ActInfoModel()
-        machine_info_model = MachineInfoModel()
-        theme_info_model = ThemeInfoModel()
-        skin_info_model = SkinInfoModel()
-        ip_series_model = IpSeriesModel()
+        act_model = ActInfoModel(context=self)
+        machine_info_model = MachineInfoModel(context=self)
+        theme_info_model = ThemeInfoModel(context=self)
+        skin_info_model = SkinInfoModel(context=self)
+        ip_series_model = IpSeriesModel(context=self)
+        act_type_model = ActTypeModel(context=self)
         theme_info = theme_info_model.get_entity()
         if not theme_info:
             return self.reponse_json_error("NoTheme", "请管理员先上传主题信息")
+        act_type_entity = act_type_model.get_entity_by_id(act_type)
+        if not act_type_entity:
+            return self.reponse_json_error("NoActType", "请管理员先配置活动类型信息")
         skin_info = skin_info_model.get_entity("theme_id=%s", params=theme_info.id)
         if not skin_info:
             return self.reponse_json_error("NoSkin", "请管理员先上传皮肤信息")
@@ -82,6 +81,9 @@ class ActCreateHandler(TopBaseHandler):
             act_info.owner_open_id = app_info.owner_open_id
             act_info.act_name = act_name
             act_info.act_type = act_type
+            act_info.currency_type = act_type_entity.currency_type
+            act_info.task_currency_type = act_type_entity.task_currency_type
+            act_info.is_task = 0
             act_info.sort_index = 1
             #默认主题ID 查询theme表得到
             act_info.theme_id = theme_info.id
@@ -138,7 +140,7 @@ class ActCreateHandler(TopBaseHandler):
             machine_info.many_lottery_price = 0
             machine_info.many_lottery_num = 0
             machine_info.is_false_prize = 1
-            machine_info.is_repeat_prize = 1
+            machine_info.is_repeat_prize = 0
             machine_info.price_gears_id = 0
             machine_info.series_id = ip_seriesid
             machine_info.specs_type = 6
@@ -175,16 +177,17 @@ class ActCreateHandler(TopBaseHandler):
                 behavior_orm.act_id = act_id
                 behavior_orm.create_date = self.get_now_datetime()
                 orm_infos.append(behavior_orm)
-            BehaviorModel().save_orm(orm_infos, act_id)
+
+            BehaviorModel(context=self).save_orm(orm_infos, act_id)
 
             self.save_default_prize(act_id, app_id, app_info.owner_open_id, machine_infoid)
 
             self.create_operation_log(OperationType.add.value, act_info.__str__(), "ActCreateHandler", None, self.json_dumps(act_info))
 
-        self.reponse_json_success(act_id)
+        return self.reponse_json_success(act_id)
 
     def save_default_prize(self, act_id, app_id, owner_open_id, machine_infoid):
-        act_prize_model = ActPrizeModel()
+        act_prize_model = ActPrizeModel(context=self)
         act_prize_list = []
         for i in range(0, 2):
             act_prize = ActPrize()
@@ -232,6 +235,7 @@ class ActHandler(SevenBaseHandler):
         :param share_desc：分享配置
         :param rule_desc：规则配置
         :param is_black：是否开启退款惩罚
+        :param is_task：是否开启任务
         :param refund_count：退款成功次数
         :param index_desc: 首页配置
         :param shakebox_tips: 摇盒提示配置
@@ -247,6 +251,7 @@ class ActHandler(SevenBaseHandler):
         share_desc = self.get_param("share_desc", "")
         rule_desc = self.get_param("rule_desc", "")
         is_black = int(self.get_param("is_black", 0))
+        is_task = int(self.get_param("is_task", 0))
         refund_count = int(self.get_param("refund_count", 0))
         store_url = self.get_param("store_url")
         index_desc = self.get_param("index_desc")
@@ -254,7 +259,7 @@ class ActHandler(SevenBaseHandler):
         shakebox_tips_num = self.get_param("shakebox_tips_num", 0)
         exceed_tips = self.get_param("exceed_tips")
 
-        act_info_model = ActInfoModel()
+        act_info_model = ActInfoModel(context=self)
         if act_id > 0:
             # 修改活动相关信息
             act_info = act_info_model.get_entity_by_id(act_id)
@@ -271,6 +276,7 @@ class ActHandler(SevenBaseHandler):
             act_info.shakebox_tips_num = shakebox_tips_num
             act_info.exceed_tips = exceed_tips
             act_info.is_black = is_black
+            act_info.is_task = is_task
             act_info.refund_count = refund_count
             act_info.store_url = store_url
             act_info.modify_date = self.get_now_datetime()
@@ -279,7 +285,86 @@ class ActHandler(SevenBaseHandler):
 
             self.create_operation_log(OperationType.update.value, act_info.__str__(), "ActHandler", self.json_dumps(old_act_info), self.json_dumps(act_info))
 
-        self.reponse_json_success()
+        return self.reponse_json_success()
+
+
+class ActSaveHandler(SevenBaseHandler):
+    """
+    :description: 保存活动
+    """
+    @filter_check_params("act_id")
+    def post_async(self):
+        """
+        :description: 修改活动
+        :param act_id：活动id
+        :param act_name：活动名称
+        :param is_release：是否发布
+        :param close_word：关闭小程序文案
+        :param share_desc：分享配置
+        :param rule_desc：规则配置
+        :param is_black：是否开启退款惩罚
+        :param is_task：是否开启任务
+        :param refund_count：退款成功次数
+        :param index_desc: 首页配置
+        :param shakebox_tips: 摇盒提示配置
+        :param shakebox_tips_num: 摇盒次数
+        :param exceed_tips: 超出次数提示内容
+        :return: 
+        :last_editors: HuangJingCan
+        """
+        act_id = int(self.get_param("act_id", 0))
+        act_name = self.get_param("act_name", "")
+        is_release = self.get_param("is_release", "")
+        close_word = self.get_param("close_word", "")
+        share_desc = self.get_param("share_desc", "")
+        rule_desc = self.get_param("rule_desc", "")
+        is_black = self.get_param("is_black", "")
+        is_task = self.get_param("is_task", "")
+        refund_count = self.get_param("refund_count", "")
+        store_url = self.get_param("store_url", "")
+        index_desc = self.get_param("index_desc", "")
+        shakebox_tips = self.get_param("shakebox_tips", "")
+        shakebox_tips_num = self.get_param("shakebox_tips_num", "")
+        exceed_tips = self.get_param("exceed_tips")
+
+        act_info_model = ActInfoModel(context=self)
+        if act_id > 0:
+            # 修改活动相关信息
+            act_info = act_info_model.get_entity_by_id(act_id)
+
+            old_act_info = deepcopy(act_info)
+
+            act_info.act_name = act_name
+            if is_release:
+                act_info.is_release = int(is_release)
+            if close_word:
+                act_info.close_word = close_word
+            if share_desc:
+                act_info.share_desc = self.json_dumps(share_desc) if share_desc != "" else {}
+            if rule_desc:
+                act_info.rule_desc = self.json_dumps(rule_desc) if rule_desc != "" else []
+            if index_desc:
+                act_info.index_desc = self.json_dumps(index_desc) if index_desc != "" else {}
+            if shakebox_tips:
+                act_info.shakebox_tips = self.json_dumps(shakebox_tips) if shakebox_tips != "" else []
+            if shakebox_tips_num:
+                act_info.shakebox_tips_num = int(shakebox_tips_num)
+            if exceed_tips:
+                act_info.exceed_tips = exceed_tips
+            if is_black:
+                act_info.is_black = int(is_black)
+            if is_task:
+                act_info.is_task = int(is_task)
+            if refund_count:
+                act_info.refund_count = int(refund_count)
+            if store_url:
+                act_info.store_url = store_url
+            act_info.modify_date = self.get_now_datetime()
+            act_info_model.update_entity(act_info)
+
+            self.create_operation_log(OperationType.update.value, act_info.__str__(), "ActHandler", self.json_dumps(old_act_info), self.json_dumps(act_info))
+
+        return self.reponse_json_success()
 
 
 class ActListHandler(SevenBaseHandler):
@@ -312,7 +397,7 @@ class ActListHandler(SevenBaseHandler):
             else:
                 condition += "AND is_del=1"
 
-            page_list, total = ActInfoModel().get_dict_page_list("*", page_index, page_size, condition, "", order_by, app_id)
+            page_list, total = ActInfoModel(context=self).get_dict_page_list("*", page_index, page_size, condition, "", order_by, app_id)
 
             for page in page_list:
                 page["share_desc"] = self.json_loads(page["share_desc"]) if page["share_desc"] else {}
@@ -326,9 +411,9 @@ class ActListHandler(SevenBaseHandler):
 
             page_info = PageInfo(page_index, page_size, total, page_list)
 
-            self.reponse_json_success(page_info)
-        else:
-            self.reponse_json_success({"data": []})
+            return self.reponse_json_success(page_info)
+
+        return self.reponse_json_success({"data": []})
 
 
 class ActInfoHandler(SevenBaseHandler):
@@ -345,7 +430,7 @@ class ActInfoHandler(SevenBaseHandler):
         """
         act_id = int(self.get_param("act_id", "0"))
 
-        act_info = ActInfoModel().get_entity_by_id(act_id)
+        act_info = ActInfoModel(context=self).get_entity_by_id(act_id)
 
         if act_info:
             act_info.share_desc = self.json_loads(act_info.share_desc)
@@ -359,6 +444,6 @@ class ActInfoHandler(SevenBaseHandler):
             act_info.online_url = self.get_online_url(act_info.id, act_info.app_id)
             act_info.live_url = self.get_live_url(act_info.app_id)
 
-            self.reponse_json_success(act_info)
-        else:
-            self.reponse_json_success()
\ No newline at end of file
+            return self.reponse_json_success(act_info)
+
+        return self.reponse_json_success()
\ No newline at end of file
